@@ -3,26 +3,35 @@ OC.L10N.register(
     {
     "Bookmarks" : "סימניות",
     "Add a Bookmark" : "הוספת סימנייה",
+    "Add folder" : "הוספת תיקייה",
     "Select" : "בחירה",
     "Deselect" : "ביטול בחירה",
     "Details" : "פרטים",
     "Delete" : "מחיקה",
     "Saved" : "נשמרה",
+    "Date added" : "מועד ההוספה",
+    "Link" : "קישור",
     "Tags" : "תגיות",
     "Description" : "תיאור",
     "No bookmarks here." : "אין כאן סימניות.",
+    "Favorites" : "מועדפים",
     "Settings" : "הגדרות",
     "Bookmarklet" : "יישומון סימנייה",
     "Add to {instanceName} " : "הוספה אל {instanceName} ",
     "Recently added" : "נוספו לאחרונה",
     "Most visited" : "הכי הרבה ביקורים",
+    "View mode" : "מצב הצגה",
+    "List view" : "תצוגת רשימה",
     "RSS Feed" : "ערוץ RSS",
     "Permanently remove all bookmarks from your account. There is no going back!" : "הסרת כל הסימניות מהחשבון שלך לצמיתות. אי אפשר לחזור אחורה!",
     "Delete all bookmarks" : "מחיקת כל הסימניות",
     "Open details" : "פתיחת פרטים",
     "An error occurred while trying to save the bookmark." : "אירעה שגיאה בעת הניסיון לשמור סימניה.",
     "Error" : "שגיאה",
+    "Uncategorized" : "ללא קטגוריה",
+    "Error parsing the import result" : "פענוח תוצאת הייבוא נתקלה בשגיאה",
     "Import completed successfully." : "הייבוא הושלם בהצלחה.",
+    "Do you really want to delete all your bookmarks?" : "למחוק את כל הסימניות שלך?",
     "Set tags" : "הגדרת תגיות",
     "Failed to import one bookmark, because: " : "הייבוא של אחת מהסימניות נכשל, הסיבה:",
     "No file provided for import" : "לא סופק קובץ לייבוא",
