@@ -2,11 +2,8 @@ OC.L10N.register(
     "bookmarks",
     {
     "Bookmarks" : "ブックマーク",
-    "Failed to import one bookmark, because: " : "ブックマークのインポートに失敗しました。原因:",
-    "No file provided for import" : "インポート用に提供されたファイルがありません",
-    "Unsupported file type for import" : "インポートにサポートされていないファイルタイプ",
     "Add a Bookmark" : "ブックマークを追加",
-    "Add folder" : "フォルダを追加",
+    "Add folder" : "フォルダーを追加",
     "Select" : "選択",
     "Deselect" : "選択解除",
     "Details" : "詳細",
@@ -35,6 +32,9 @@ OC.L10N.register(
     "Import completed successfully." : "インポートに成功しました",
     "Do you really want to delete all your bookmarks?" : "本当にすべてのブックマークを削除しますか？",
     "Set tags" : "タグを設定",
+    "Failed to import one bookmark, because: " : "ブックマークのインポートに失敗しました。原因:",
+    "No file provided for import" : "インポート用に提供されたファイルがありません",
+    "Unsupported file type for import" : "インポートにサポートされていないファイルタイプ",
     "A Bookmark manager for Nextcloud" : "Nextcloud のブックマークマネージャー",
     "Add a bookmark" : "ブックマークを追加",
     "This URL is already bookmarked! Overwrite?" : "このURLはすでにブックマークされています! 上書きしますか?",
