@@ -2,9 +2,6 @@ OC.L10N.register(
     "bookmarks",
     {
     "Bookmarks" : "Bokmärken",
-    "Failed to import one bookmark, because: " : "Misslyckades att importera bokmärken eftersom:",
-    "No file provided for import" : "Inga filer given för importering",
-    "Unsupported file type for import" : "Ogiltig filtyp för import",
     "Add a Bookmark" : "Lägg till ett bokmärke",
     "Add folder" : "Lägg till mapp",
     "Select" : "Välj",
@@ -36,6 +33,9 @@ OC.L10N.register(
     "Import completed successfully." : "Importen slutfördes utan problem.",
     "Do you really want to delete all your bookmarks?" : "Vill du verkligen radera alla dina bokmärken?",
     "Set tags" : "Ange taggar",
+    "Failed to import one bookmark, because: " : "Misslyckades att importera bokmärken eftersom:",
+    "No file provided for import" : "Inga filer given för importering",
+    "Unsupported file type for import" : "Ogiltig filtyp för import",
     "A Bookmark manager for Nextcloud" : "En bokmärkeshanterare för Nextcloud",
     "Add a bookmark" : "Lägg till ett bokmärke",
     "This URL is already bookmarked! Overwrite?" : "Den här webbadressen är redan bokmärkt! Skriva över?",
@@ -44,7 +44,7 @@ OC.L10N.register(
     "Description of the page" : "Sidans beskrivning",
     "Save" : "Spara",
     "Previews" : "Förhandsvisningar",
-    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "För att kunna visa riktiga skärmdumpar av dina bokmärkta webbplatser kan bokmärken använda en tredjepartstjänst för att generera dom.",
+    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "För att kunna visa riktiga skärmdumpar av dina bokmärkta webbplatser kan bokmärken använda en tredjepartstjänst för att generera dem.",
     "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Du kan antingen registrera dig gratis hos <a href=\"http://screeenly.com\">screeenly.com</a> eller <a href=\"https://github.com/stefanzweifel/screeenly\">sätta upp din egen server</a>.",
     "Screenly API URL" : "Screenly API URL",
     "Screenly API key" : "Screenly API-nyckel",
